@@ -31,11 +31,6 @@
 #include <glib/gi18n-lib.h>
 
 #include <e-util/e-util.h>
-#include <e-util/e-dialog-utils.h>
-#include <e-util/e-plugin-ui.h>
-
-#include <libevolution-utils/e-alert.h>
-#include <misc/e-alert-bar.h>
 
 #include <libekolabutil/kolab-util-folder.h>
 
