@@ -91,7 +91,7 @@ conv_kolab_conv_mail_to_I_contact (const Kolab_conv_mail* k_contact, GError** er
 	/* find root node */
 	for (n_ptr = doc->children; n_ptr != NULL; n_ptr = n_ptr->next)
 		if (n_ptr->type == XML_ELEMENT_NODE &&
-				g_strcmp0((gchar*)n_ptr->name, KLB_CNT) == 0)
+		    g_strcmp0((gchar*)n_ptr->name, KLB_CNT) == 0)
 			node = n_ptr;
 	if (node == NULL) {
 		g_set_error (error, KOLABCONV_ERROR_READ_KOLAB,
@@ -180,7 +180,7 @@ process_attachments_k_to_i (I_contact* i_contact, GError** error)
 			i_contact->photo = mail_part;
 
 			i_contact->common->kolab_attachment_store =
-					g_list_remove(i_contact->common->kolab_attachment_store, (gconstpointer) mail_part);
+				g_list_remove(i_contact->common->kolab_attachment_store, (gconstpointer) mail_part);
 		} else
 			i_contact->photo = NULL;
 
@@ -433,9 +433,9 @@ handle_element_email (I_contact *i_contact, const xmlNodePtr node)
 		child = text->next;
 		child_contents = child->children;
 
-		 if (strcmp ((gchar *) child->name, KLB_CNT_EMAIL_SMTP_ADDRESS) == 0)
+		if (strcmp ((gchar *) child->name, KLB_CNT_EMAIL_SMTP_ADDRESS) == 0)
 			email->smtp_address = g_string_new ((gchar *) child_contents->content);
-		 else
+		else
 			i_kolab_store_add_xml_element(i_contact->common, email, child);
 
 		text = child->next;
@@ -502,9 +502,7 @@ handle_element_address (I_contact *i_contact, const xmlNodePtr node)
 		/* TODO Remove, if needed, child-element from store, because in this case full address will be put in kolab store. */
 		/* g_hash_table_remove(i_contact->common->kolab_store, child); */
 		return FALSE;	/* return element not handled, then will be put in kolab store */
-	}
-	else
-	{
+	} else {
 		i_contact->addresses = g_list_append (i_contact->addresses, (Address *) address);
 		return TRUE;
 	}
@@ -528,15 +526,13 @@ handle_contact_name (I_contact *i_contact, xmlNodePtr node)
 	/* iterate over all child elements of node an process them */
 	for (n_ptr = node->children; n_ptr != NULL; n_ptr = n_ptr->next) {
 		if (n_ptr->type == XML_ELEMENT_NODE) {
-			if(
-				handle_element_string(KLB_CNT_NAME_GIVEN_NAME, &i_contact->given_name, n_ptr) ||
-				handle_element_string(KLB_CNT_NAME_MIDDLE_NAMES, &i_contact->middle_names, n_ptr) ||
-				handle_element_string(KLB_CNT_NAME_LAST_NAME, &i_contact->last_name, n_ptr) ||
-				handle_element_string(KLB_CNT_NAME_FULL_NAME, &i_contact->full_name, n_ptr) ||
-				/* TODO: Contact: <initials> ?!!! */
-				handle_element_string(KLB_CNT_NAME_PREFIX, &i_contact->prefix, n_ptr) ||
-				handle_element_string(KLB_CNT_NAME_SUFFIX, &i_contact->suffix, n_ptr)
-			)
+			if (handle_element_string(KLB_CNT_NAME_GIVEN_NAME, &i_contact->given_name, n_ptr) ||
+			    handle_element_string(KLB_CNT_NAME_MIDDLE_NAMES, &i_contact->middle_names, n_ptr) ||
+			    handle_element_string(KLB_CNT_NAME_LAST_NAME, &i_contact->last_name, n_ptr) ||
+			    handle_element_string(KLB_CNT_NAME_FULL_NAME, &i_contact->full_name, n_ptr) ||
+			    /* TODO: Contact: <initials> ?!!! */
+			    handle_element_string(KLB_CNT_NAME_PREFIX, &i_contact->prefix, n_ptr) ||
+			    handle_element_string(KLB_CNT_NAME_SUFFIX, &i_contact->suffix, n_ptr))
 				continue;
 
 			i_kolab_store_add_xml_element(i_contact->common, (gpointer) KOLAB_STORE_PTR_CONTACT_NAME, n_ptr);
